starcluster.logger

Package starcluster :: Module logger |
[hide private]
[frames] | no frames]

# Module logger

source code

StarCluster logging module

Classes | [hide private]
| ConsoleLogger
| NullHandler

Functions | [hide private]
get_starcluster_logger() | source code
configure_sc_logging(use_syslog=False) Configure logging for StarCluster *application* code | source code
configure_paramiko_logging() Configure paramiko to log to a file for debug | source code
configure_boto_logging() Configure boto to log to a file for debug | source code

Variables | [hide private]
| INFO = `20`
| DEBUG = `10`
| WARN = `30`
| ERROR = `40`
| CRITICAL = `50`
| FATAL = `50`
| RAW_FORMAT = ``'``%(message)s\n``'``
| INFO_FORMAT = ``'``>>> %(message)s\n``'``
| DEBUG_FORMAT = ``'``%(filename)s:%(lineno)d - %(levelname)s - %(me``...``
| DEBUG_FORMAT_PID = ``'``PID: 13792 %(filename)s:%(lineno)d - %(lev``...``
| DEFAULT_CONSOLE_FORMAT = ``'``%(levelname)s - %(message)s\n``'``
| ERROR_CONSOLE_FORMAT = ``'``!!! %(levelname)s - %(message)s\n``'``
| WARN_CONSOLE_FORMAT = ``'``*** %(levelname)s - %(message)s\n``'``
| log = `get_starcluster_logger()`
| console = `ConsoleLogger()`
| __package__ = ``'``starcluster``'``

Function Details | [hide private]

### configure_sc_logging(use_syslog=False) | source code
Configure logging for StarCluster *application* code By default StarCluster's logger has no formatters and a NullHandler so that other developers using StarCluster as a library can configure logging as they see fit. This method is used in StarCluster's application code (ie the 'starcluster' command) to toggle StarCluster's application specific formatters/handlers use_syslog - enable logging all messages to syslog. currently only works if /dev/log exists on the system (standard for most Linux distros)

Variables Details | [hide private]

  ### DEBUG_FORMAT Value:
      '''%(filename)s:%(lineno)d - %(levelname)s - %(message)s
      '''

  ### DEBUG_FORMAT_PID Value:
      '''PID: 13792 %(filename)s:%(lineno)d - %(levelname)s - %(message)s
      '''